@@ -46,7 +46,6 @@ class AbstractAdministrativeAreaLevel1Model(models.Model):
     code = models.CharField(_("Code"), max_length=5, blank=True, default="")
     country = models.ForeignKey(
         to=swapper.get_model_name("django_address", "Country"), on_delete=models.PROTECT, verbose_name=_("Country"),
-        related_name="level1_areas"
     )
 
     objects = GetOrNoneManager()
@@ -126,8 +125,7 @@ class AbstractStreetModel(models.Model):
     """Abstract street model."""
 
     locality = models.ForeignKey(
-        to=swapper.get_model_name("django_address", "Locality"), on_delete=models.CASCADE, verbose_name=_("Locality"),
-        related_name="streets"
+        to=swapper.get_model_name("django_address", "Locality"), on_delete=models.CASCADE, verbose_name=_("Locality")
     )
     name = models.CharField(_("Street name"), max_length=256)
 
@@ -155,14 +153,12 @@ class AbstractAddressModel(models.Model):
         on_delete=models.CASCADE,
         verbose_name=_("Locality"),
         null=True,
-        related_name="addresses"
     )
     street = models.ForeignKey(
         to=swapper.get_model_name("django_address", "Street"),
         on_delete=models.CASCADE,
         verbose_name=_("Street"),
         null=True,
-        related_name="addresses"
     )
     raw = models.CharField(_("Raw"), max_length=256, blank=True, default="")
     route = models.CharField(_("Route"), max_length=256, default="")
@@ -294,6 +290,11 @@ class Locality(AbstractLocalityModel):
 class Street(AbstractStreetModel):
     """Street model."""
 
+    locality = models.ForeignKey(
+        to=swapper.get_model_name("django_address", "Locality"), on_delete=models.CASCADE, verbose_name=_("Locality"),
+        related_name="streets"
+    )
+
     class Meta(AbstractStreetModel.Meta):
         swappable = swapper.swappable_setting("django_address", "Street")
 
@@ -301,6 +302,21 @@ class Street(AbstractStreetModel):
 class Address(AbstractAddressModel):
     """Address model."""
 
+    locality = models.ForeignKey(
+        to=swapper.get_model_name("django_address", "Locality"),
+        on_delete=models.CASCADE,
+        verbose_name=_("Locality"),
+        null=True,
+        related_name="addresses"
+    )
+    street = models.ForeignKey(
+        to=swapper.get_model_name("django_address", "Street"),
+        on_delete=models.CASCADE,
+        verbose_name=_("Street"),
+        null=True,
+        related_name="addresses"
+    )
+
     class Meta(AbstractAddressModel.Meta):
         swappable = swapper.swappable_setting("django_address", "Address")
 
